//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[ChildPoint](index.md)/[tsumoChild](tsumo-child.md)

# tsumoChild

[common]\
val [tsumoChild](tsumo-child.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

自摸子家（闲家）点数
